@@ -24,6 +24,7 @@ pub fn init(v8_flags: Option<Vec<String>>) {
 }
 
 /// Options for `JSTime::new`.
+#[derive(Default)]
 pub struct Options {
     pub snapshot: Option<&'static [u8]>,
     taking_snapshot: bool,
@@ -38,15 +39,6 @@ impl Options {
     }
 }
 
-impl Default for Options {
-    fn default() -> Options {
-        Options {
-            snapshot: None,
-            taking_snapshot: false,
-        }
-    }
-}
-
 /// JSTime Instance.
 #[allow(clippy::all)]
 pub struct JSTime {
